@@ -1,7 +1,6 @@
 from pymdownx.superfences import _escape
-from pymdownx.superfences import SuperFencesException, fence_code_format
+from pymdownx.superfences import fence_code_format
 
-from mkdocs.exceptions import PluginError
 
 import json
 
@@ -10,7 +9,9 @@ def fence_plotly(source, language, class_name, options, md, **kwargs):
         data = json.loads(source)
     except Exception:
         return fence_code_format(source, language, class_name, options, md, **kwargs)
+    classes = [class_name] + kwargs['classes']
+    classes_str = " ".join(classes)
     if data.get('file_path'):
         file_path = str(data['file_path'])
-        return f'<div class="plotly-chart" data-jsonpath={file_path}></div>'
-    return f'<div class="plotly-chart">{_escape(source)}</div>'
+        return f'<div class="{classes_str}" data-jsonpath={file_path}></div>'
+    return f'<div class="{classes_str}">{_escape(source)}</div>'
